@@ -803,7 +803,7 @@ def testRegions(server, admin, fsAssetstore):
     resp = server.request(path='/item/%s/tiles/region' % itemId,
                           user=admin, isJson=False, params=params)
     assert utilities.respStatus(resp) == 200
-    image = origImage = utilities.getBody(resp, text=False)
+    image = utilities.getBody(resp, text=False)
     assert image[:len(utilities.BigTIFFHeader)] == utilities.BigTIFFHeader
 
 
@@ -1186,6 +1186,32 @@ def testTilesInternalMetadata(server, admin, fsAssetstore):
     assert resp.json['tilesource'] == 'tiff'
 
 
+@pytest.mark.usefixtures('unbindLargeImage')
+@pytest.mark.plugin('large_image')
+def testTilesBandInformation(server, admin, fsAssetstore):
+    file = utilities.uploadExternalFile(
+        'sample_Easy1.png', admin, fsAssetstore)
+    itemId = str(file['itemId'])
+    server.request(path='/item/%s/tiles' % itemId, method='POST', user=admin)
+    resp = server.request(path='/item/%s/tiles/bands' % itemId)
+    assert len(resp.json) == 4
+    assert resp.json[0]['interpretation'] == 'red'
+    assert 'mean' in resp.json[0]
+
+
+@pytest.mark.usefixtures('unbindLargeImage')
+@pytest.mark.plugin('large_image')
+def testTilesBandInformationWithFrames(server, admin, fsAssetstore):
+    file = utilities.uploadExternalFile(
+        'sample.ome.tif', admin, fsAssetstore)
+    itemId = str(file['itemId'])
+    resp = server.request(path='/item/%s/tiles/bands' % itemId)
+    assert len(resp.json) == 1
+    resp2 = server.request(path='/item/%s/tiles/bands' % itemId, params={'frame': 1})
+    assert len(resp2.json) == 1
+    assert resp != resp2
+
+
 @pytest.mark.usefixtures('unbindLargeImage')
 @pytest.mark.plugin('large_image')
 def testTilesFromMultipleDotName(boundServer, admin, fsAssetstore, girderWorker):
@@ -1297,3 +1323,34 @@ def testTilesConvertRemote(boundServer, admin, fsAssetstore, girderWorker):
     assert tileMetadata['mm_x'] is None
     assert tileMetadata['mm_y'] is None
     _testTilesZXY(boundServer, admin, itemId, tileMetadata)
+
+
+@pytest.mark.usefixtures('unbindLargeImage')
+@pytest.mark.plugin('large_image')
+def testTileFrames(server, admin, fsAssetstore):
+    file = utilities.uploadExternalFile(
+        'sample.ome.tif', admin, fsAssetstore)
+    itemId = str(file['itemId'])
+    params = {
+        'width': 200,
+        'height': 200}
+    resp = server.request(path='/item/%s/tiles/tile_frames' % itemId,
+                          user=admin, isJson=False, params=params)
+    assert utilities.respStatus(resp) == 200
+
+    params['cache'] = 'true'
+    resp = server.request(path='/item/%s/tiles/tile_frames' % itemId,
+                          user=admin, isJson=False, params=params)
+    assert utilities.respStatus(resp) == 200
+
+    resp = server.request(path='/item/%s/tiles/tile_frames' % itemId,
+                          user=admin, isJson=False, params=params)
+    assert utilities.respStatus(resp) == 200
+
+    params['encoding'] = 'TILED'
+    params['frameList'] = '0,2'
+    resp = server.request(path='/item/%s/tiles/tile_frames' % itemId,
+                          user=admin, isJson=False, params=params)
+    assert utilities.respStatus(resp) == 200
+    image = utilities.getBody(resp, text=False)
+    assert image[:len(utilities.BigTIFFHeader)] == utilities.BigTIFFHeader
